@@ -4,18 +4,30 @@ import sys
 import os
 import re
 
-sys.path.append(os.path.abspath('..'))
+# If we are building locally, or the build on Read the Docs looks like a PR
+# build, prefer to use the version of the theme in this repo, not the installed
+# version of the theme.
+def is_development_build():
+    # PR builds have an interger version
+    re_version = re.compile(r'^[\d]+$')
+    if 'READTHEDOCS' in os.environ:
+        version = os.environ.get('READTHEDOCS_VERSION', '')
+        if re_version.match(version):
+            return True
+        return False
+    return True
+
+if is_development_build():
+    sys.path.insert(0, os.path.abspath('..'))
 sys.path.append(os.path.abspath('./demo/'))
 
+import sphinx_rtd_theme
 from sphinx.locale import _
 
-from sphinx_rtd_theme import __version__
-
-
 project = u'Read the Docs Sphinx Theme'
 slug = re.sub(r'\W+', '-', project.lower())
-version = __version__
-release = __version__
+version = '0.5.0'
+release = '0.5.0'
 author = u'Dave Snider, Read the Docs, Inc. & contributors'
 copyright = author
 language = 'en'
@@ -26,11 +38,14 @@ extensions = [
     'sphinx.ext.mathjax',
     'sphinx.ext.viewcode',
     'sphinxcontrib.httpdomain',
+    'sphinx_rtd_theme',
 ]
 
 templates_path = ['_templates']
 source_suffix = '.rst'
 exclude_patterns = []
+locale_dirs = ['locale/']
+gettext_compact = False
 
 master_doc = 'index'
 suppress_warnings = ['image.nonlocal_uri']
@@ -43,14 +58,27 @@ intersphinx_mapping = {
 
 html_theme = 'sphinx_rtd_theme'
 html_theme_options = {
-    'logo_only': True
+    'logo_only': True,
+    'navigation_depth': 5,
 }
-html_theme_path = ["../.."]
+html_context = {}
+
+if not 'READTHEDOCS' in os.environ:
+    html_static_path = ['_static/']
+    html_js_files = ['debug.js']
+
+    # Add fake versions for local QA of the menu
+    html_context['test_versions'] = list(map(
+        lambda x: str(x / 10),
+        range(1, 100)
+    ))
+
 html_logo = "demo/static/logo-wordmark-light.svg"
 html_show_sourcelink = True
 
 htmlhelp_basename = slug
 
+
 latex_documents = [
   ('index', '{0}.tex'.format(slug), project, author, 'manual'),
 ]
